#!/usr/bin/python

#
# Copyright (C) 2011-2013 Finnbarr P. Murphy
#
# This needs to be modified for each new release added
#

#
# Copyright (C) 2008 Canonical Ltd.
#
# This code was originally written by Dustin Kirkland <kirkland@ubuntu.com>,
# based on a framework by Kees Cook <kees@ubuntu.com>.
#

#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import cgi
import glob
import os
import re

# FPM update as required for each new release
# next version will require more styling to fix layout
# coming near limits

# versions = dict(fedora12="<center>F12</center>", 
#                fedora13="<center>F13</center>", 
#                fedora14="<center>F14</center>",
#                fedora15="<center>F15</center>",
#                fedora16="<center>F16</center>",
#                fedora17="<center>F17</center>",
#                fedora18="<center>F18</center>",
#                fedora19="<center>F19</center>",
#                fedora20="<center>F20</center>",
#                fedora21="<center>F21</center>");

# FPM 12/27/2014  Modified to only show last 7 versions
versions = dict(fedora15="<center>F15</center>",
                fedora16="<center>F16</center>",
                fedora17="<center>F17</center>",
                fedora18="<center>F18</center>",
                fedora19="<center>F19</center>",
                fedora20="<center>F20</center>",
                fedora21="<center>F21</center>");

html = "Content-Type: text/html\n\n"
html += open("includes/header1.html").read()
html += "Search"
html += open("includes/header2.html").read()

get = cgi.FieldStorage()
p1 = re.compile( '^\.\.' );
p2 = re.compile( '.*\/' );
p3 = re.compile( '\.html$' );
p4 = re.compile( '\.[0-9].*$' );
p5 = re.compile( ', $' );

# Google Custom Search Engine (CSE) results 
google_cse_html = '''
<div id="cse-search-results"></div>
<script type="text/javascript">
  var googleSearchIframeName = "cse-search-results";
  var googleSearchFormName = "cse-search-box";
  var googleSearchFrameWidth = 670;
  var googleSearchFrameHeight = 1000;
  var googleSearchDomain = "www.google.com";
  var googleSearchPath = "/cse";
  var googleSearchResizeIframe = true;
</script>
<script type="text/javascript" src="http://linuxmanpages.net/js/show_afs_search.js"></script>
<script type="text/javascript">
 try{document.getElementsByName('googleSearchFrame')[0].height=1200;}catch(e){}
</script>
'''

# section descriptions
section_descriptions = [
   "Headers (0p)",
   "Commands/Utilities (1)", 
   "Commands/Utilities (1p)",
   "System Routines (2)",
   "Library Routines (3)",
   "Library Routines (3p)",
   "Library Routines (3t)",
   "Library Routines (3z)",
   "Special Files (4)",
   "File Formats (5)",
   "Games (6)",
   "Games (6x)",
   "Miscellaneous (7)",
   "System Adminstration (8)",
   "Kernel Routines (9)"
]

# number of items here MUST match number of section descriptions
sections = [
   "0p",
   "1",
   "1p",
   "2",
   "3",
   "3p",
   "3t",
   "3z",
   "4",
   "5",
   "6",
   "6x",
   "7",
   "8",
   "9"
]


t = ""
if get.has_key("q"):
    t = get["q"].value

p = re.compile( '[^\.a-zA-Z0-9\/_\:\+@-]' );
t = p.sub('', t)
title_html = "<script>document.forms[0].q.value='" + t + "';</script>"

# language - FPM ignored
if get.has_key("lr"):
    lr = get["lr"].value
    p = re.compile( '^lang_' );
    lr = p.sub('', lr)
    p = re.compile( '[^a-zA-Z-]' );
    lr = p.sub('', lr)
    p = re.compile( '[-]' );
    lr = p.sub('_', lr)
else:
    lr = "en"

distros = versions.keys()
distros.sort()

title_html += "<br><b>Note: Due to space limitations, only the last 7 Fedora releases are searched and listed here. You can use the menu buttons above to manually seach earlier Fedora releases.</b></br>"
title_html += "<br><table border='2' cellpadding='5' cellspacing='0'>"
title_html += "<tr><td><table cellspacing='0' cellpadding='0'><tr>"
title_html += "<th id='sdheader' >Section Description</th>"
for d in distros:
    title_html += "<th>%s</th>" % (versions[d])
title_html += "</tr>"

matches = 0
for section in range(0, len(section_descriptions)):
    title_html += '<tr><td id="sdcontent">%s</td>' % (section_descriptions[section])
    for d in distros:
        # FPM careful! fix this up if you change location of reference pages 
        path = "manpages/%s/man%s/%s.%s.html" % (d, sections[section], t, sections[section])
        title_html += "<td align=center>"
        dot = '<img src="/images/notok.png" width="15px" height="15px"/>'
        for g in glob.glob(path):
            matches += 1
            dot = ""
            href_path = p1.sub('', g)
            page = p2.sub('', g)
            page = p3.sub('', page)
            page = p4.sub('', page)
            # FPM - change this to ICON of some short - eliminates varying width issue!
            #title_html += '<a href="%s" style="text-decoration:none">%s</a>, ' % (href_path, page)
            title_html += '<a href="%s" style="text-decoration:none"><img src="/images/ok.png" width="15px" height="15px" /></a>, ' % (href_path)
        title_html = p5.sub('', title_html)
        title_html += dot + "</td>"
    title_html += "</tr>"

title_html += "</table></td></tr></table><br>"

if (matches > 0):
    if get.has_key("titles") and get["titles"].value == "404":
        # If we were sent here by a 404-not-found, and we have at least one match,
        # redirect the user to the last page in our list
        html += "<script>location.replace('" + href_path + "');</script>"
    else:
        # Otherwise, a normal title search, display the title table
        html += title_html
else:
    # But if we do not find any matching titles, do a full text search
    html += "<strong>No matching manpage titles found.</strong>"

html += google_cse_html
html += open("includes/footer1.html").read()

print html
